@@ -51,14 +51,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.cx_api
-import cdk_nag
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.cx_api as _aws_cdk_cx_api_ceddda9d
+import cdk_nag as _cdk_nag_263d9695
+import constructs as _constructs_77d1e7e8
 
 
 class AwsPrototypingChecks(
-    cdk_nag.NagPack,
+    _cdk_nag_263d9695.NagPack,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-prototyping-sdk/pdk-nag.AwsPrototypingChecks",
 ):
@@ -76,22 +76,20 @@ class AwsPrototypingChecks(
         :param reports: Whether or not to generate CSV compliance reports for applied Stacks in the App's output directory (default: true).
         :param verbose: Whether or not to enable extended explanatory descriptions on warning, error, and logged ignore messages (default: false).
         '''
-        props = cdk_nag.NagPackProps(
+        props = _cdk_nag_263d9695.NagPackProps(
             log_ignores=log_ignores, reports=reports, verbose=verbose
         )
 
         jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="visit")
-    def visit(self, node: constructs.IConstruct) -> None:
+    def visit(self, node: _constructs_77d1e7e8.IConstruct) -> None:
         '''Check if CfnResource and apply rules.
 
         :param node: -
         '''
         if __debug__:
-            def stub(node: constructs.IConstruct) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ac3cb3e86fec8343c8cfd3250603139c2b784e953e810dd5f4ec86bea8647470)
             check_type(argname="argument node", value=node, expected_type=type_hints["node"])
         return typing.cast(None, jsii.invoke(self, "visit", [node]))
 
@@ -117,16 +115,10 @@ class Message:
         :param message_type: Message type as returned from cdk-nag.
         '''
         if __debug__:
-            def stub(
-                *,
-                message_description: builtins.str,
-                message_type: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8b4717233c383e92aee07f5c5bfaaf9ba416f2612bb2527190abf127c7d11614)
             check_type(argname="argument message_description", value=message_description, expected_type=type_hints["message_description"])
             check_type(argname="argument message_type", value=message_type, expected_type=type_hints["message_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "message_description": message_description,
             "message_type": message_type,
         }
@@ -166,7 +158,7 @@ class NagResult:
     def __init__(
         self,
         *,
-        messages: typing.Sequence[typing.Union[Message, typing.Dict[str, typing.Any]]],
+        messages: typing.Sequence[typing.Union[Message, typing.Dict[builtins.str, typing.Any]]],
         resource: builtins.str,
     ) -> None:
         '''Nag result.
@@ -175,16 +167,10 @@ class NagResult:
         :param resource: Resource which triggered the message.
         '''
         if __debug__:
-            def stub(
-                *,
-                messages: typing.Sequence[typing.Union[Message, typing.Dict[str, typing.Any]]],
-                resource: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__466a7c08b7dcfd34459cbd9fbc047f17fa25c1fe7475d27c9da99cbe48725576)
             check_type(argname="argument messages", value=messages, expected_type=type_hints["messages"])
             check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "messages": messages,
             "resource": resource,
         }
@@ -225,9 +211,9 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
     @builtins.classmethod
     def add_resource_suppressions_by_path_no_throw(
         cls,
-        stack: aws_cdk.Stack,
+        stack: _aws_cdk_ceddda9d.Stack,
         path: builtins.str,
-        suppressions: typing.Sequence[typing.Union[cdk_nag.NagPackSuppression, typing.Dict[str, typing.Any]]],
+        suppressions: typing.Sequence[typing.Union[_cdk_nag_263d9695.NagPackSuppression, typing.Dict[builtins.str, typing.Any]]],
         apply_to_children: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Wrapper around NagSuppressions which does not throw.
@@ -238,14 +224,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         :param apply_to_children: whether to apply to children.
         '''
         if __debug__:
-            def stub(
-                stack: aws_cdk.Stack,
-                path: builtins.str,
-                suppressions: typing.Sequence[typing.Union[cdk_nag.NagPackSuppression, typing.Dict[str, typing.Any]]],
-                apply_to_children: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__eacd5d6263c6650ef92801e14df0e8496ba14fc314027ecdc8ab17feeb1ee6cb)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
             check_type(argname="argument suppressions", value=suppressions, expected_type=type_hints["suppressions"])
@@ -259,7 +238,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         *,
         fail_on_error: typing.Optional[builtins.bool] = None,
         fail_on_warning: typing.Optional[builtins.bool] = None,
-        nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
+        nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
         analytics_reporting: typing.Optional[builtins.bool] = None,
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
@@ -277,7 +256,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
-        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The {@link AppProps.context} property This property is recommended over the {@link AppProps.context} property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
+        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         '''
@@ -298,35 +277,31 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
 
     @jsii.member(jsii_name="getStackAccountRegex")
     @builtins.classmethod
-    def get_stack_account_regex(cls, stack: aws_cdk.Stack) -> builtins.str:
+    def get_stack_account_regex(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
         '''Returns a stack account regex.
 
         :param stack: stack instance.
         '''
         if __debug__:
-            def stub(stack: aws_cdk.Stack) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f531ce8dc9530de5f5a780dfb0a7d65e878015fc527a8a2910fa6ff9524c076b)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackAccountRegex", [stack]))
 
     @jsii.member(jsii_name="getStackPartitionRegex")
     @builtins.classmethod
-    def get_stack_partition_regex(cls, stack: aws_cdk.Stack) -> builtins.str:
+    def get_stack_partition_regex(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
         '''Returns a stack partition regex.
 
         :param stack: stack instance.
         '''
         if __debug__:
-            def stub(stack: aws_cdk.Stack) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4c4670d27463fdb902c062007f0ce99b8693abca99d353e2cfa1717c0ef5c2ca)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPartitionRegex", [stack]))
 
     @jsii.member(jsii_name="getStackPrefix")
     @builtins.classmethod
-    def get_stack_prefix(cls, stack: aws_cdk.Stack) -> builtins.str:
+    def get_stack_prefix(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
         '''Returns a prefix comprising of a delimited set of Stack Ids.
 
         For example: StackA/NestedStackB/
@@ -334,29 +309,25 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         :param stack: stack instance.
         '''
         if __debug__:
-            def stub(stack: aws_cdk.Stack) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2c7f927b35737240cc577c142b301cdf0a408f1b8d83de2f004c52b876d04688)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPrefix", [stack]))
 
     @jsii.member(jsii_name="getStackRegionRegex")
     @builtins.classmethod
-    def get_stack_region_regex(cls, stack: aws_cdk.Stack) -> builtins.str:
+    def get_stack_region_regex(cls, stack: _aws_cdk_ceddda9d.Stack) -> builtins.str:
         '''Returns a stack region regex.
 
         :param stack: stack instance.
         '''
         if __debug__:
-            def stub(stack: aws_cdk.Stack) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3a89a363b3c85ca82ba617bc4d5467add15ae50a34fde9d5a6c3050821178320)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackRegionRegex", [stack]))
 
 
 class PDKNagApp(
-    aws_cdk.App,
+    _aws_cdk_ceddda9d.App,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-prototyping-sdk/pdk-nag.PDKNagApp",
 ):
@@ -369,7 +340,7 @@ class PDKNagApp(
         *,
         fail_on_error: typing.Optional[builtins.bool] = None,
         fail_on_warning: typing.Optional[builtins.bool] = None,
-        nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
+        nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
         analytics_reporting: typing.Optional[builtins.bool] = None,
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
@@ -386,7 +357,7 @@ class PDKNagApp(
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
-        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The {@link AppProps.context} property This property is recommended over the {@link AppProps.context} property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
+        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         '''
@@ -409,7 +380,7 @@ class PDKNagApp(
     def add_nag_result(
         self,
         *,
-        messages: typing.Sequence[typing.Union[Message, typing.Dict[str, typing.Any]]],
+        messages: typing.Sequence[typing.Union[Message, typing.Dict[builtins.str, typing.Any]]],
         resource: builtins.str,
     ) -> None:
         '''
@@ -435,7 +406,7 @@ class PDKNagApp(
         force: typing.Optional[builtins.bool] = None,
         skip_validation: typing.Optional[builtins.bool] = None,
         validate_on_synthesis: typing.Optional[builtins.bool] = None,
-    ) -> aws_cdk.cx_api.CloudAssembly:
+    ) -> _aws_cdk_cx_api_ceddda9d.CloudAssembly:
         '''Synthesize this stage into a cloud assembly.
 
         Once an assembly has been synthesized, it cannot be modified. Subsequent
@@ -445,23 +416,23 @@ class PDKNagApp(
         :param skip_validation: Should we skip construct validation. Default: - false
         :param validate_on_synthesis: Whether the stack should be validated after synthesis to check for error metadata. Default: - false
         '''
-        options = aws_cdk.StageSynthesisOptions(
+        options = _aws_cdk_ceddda9d.StageSynthesisOptions(
             force=force,
             skip_validation=skip_validation,
             validate_on_synthesis=validate_on_synthesis,
         )
 
-        return typing.cast(aws_cdk.cx_api.CloudAssembly, jsii.invoke(self, "synth", [options]))
+        return typing.cast(_aws_cdk_cx_api_ceddda9d.CloudAssembly, jsii.invoke(self, "synth", [options]))
 
     @builtins.property
     @jsii.member(jsii_name="nagPacks")
-    def nag_packs(self) -> typing.List[cdk_nag.NagPack]:
-        return typing.cast(typing.List[cdk_nag.NagPack], jsii.get(self, "nagPacks"))
+    def nag_packs(self) -> typing.List[_cdk_nag_263d9695.NagPack]:
+        return typing.cast(typing.List[_cdk_nag_263d9695.NagPack], jsii.get(self, "nagPacks"))
 
 
 @jsii.data_type(
     jsii_type="@aws-prototyping-sdk/pdk-nag.PDKNagAppProps",
-    jsii_struct_bases=[aws_cdk.AppProps],
+    jsii_struct_bases=[_aws_cdk_ceddda9d.AppProps],
     name_mapping={
         "analytics_reporting": "analyticsReporting",
         "auto_synth": "autoSynth",
@@ -475,7 +446,7 @@ class PDKNagApp(
         "nag_packs": "nagPacks",
     },
 )
-class PDKNagAppProps(aws_cdk.AppProps):
+class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
     def __init__(
         self,
         *,
@@ -488,14 +459,14 @@ class PDKNagAppProps(aws_cdk.AppProps):
         tree_metadata: typing.Optional[builtins.bool] = None,
         fail_on_error: typing.Optional[builtins.bool] = None,
         fail_on_warning: typing.Optional[builtins.bool] = None,
-        nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
+        nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
     ) -> None:
         '''
         :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
-        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The {@link AppProps.context} property This property is recommended over the {@link AppProps.context} property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
+        :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
@@ -505,21 +476,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
         :inheritDoc: true
         '''
         if __debug__:
-            def stub(
-                *,
-                analytics_reporting: typing.Optional[builtins.bool] = None,
-                auto_synth: typing.Optional[builtins.bool] = None,
-                context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-                outdir: typing.Optional[builtins.str] = None,
-                post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-                stack_traces: typing.Optional[builtins.bool] = None,
-                tree_metadata: typing.Optional[builtins.bool] = None,
-                fail_on_error: typing.Optional[builtins.bool] = None,
-                fail_on_warning: typing.Optional[builtins.bool] = None,
-                nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e3e803ce90b5c2282434281a79f47263fc4a4888d6182a6d59c4b475a73fc399)
             check_type(argname="argument analytics_reporting", value=analytics_reporting, expected_type=type_hints["analytics_reporting"])
             check_type(argname="argument auto_synth", value=auto_synth, expected_type=type_hints["auto_synth"])
             check_type(argname="argument context", value=context, expected_type=type_hints["context"])
@@ -530,7 +487,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
             check_type(argname="argument fail_on_error", value=fail_on_error, expected_type=type_hints["fail_on_error"])
             check_type(argname="argument fail_on_warning", value=fail_on_warning, expected_type=type_hints["fail_on_warning"])
             check_type(argname="argument nag_packs", value=nag_packs, expected_type=type_hints["nag_packs"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if analytics_reporting is not None:
             self._values["analytics_reporting"] = analytics_reporting
         if auto_synth is not None:
@@ -618,9 +575,9 @@ class PDKNagAppProps(aws_cdk.AppProps):
 
         - The CLI via --context
         - The ``context`` key in ``cdk.json``
-        - The {@link AppProps.context} property
+        - The ``AppProps.context`` property
 
-        This property is recommended over the {@link AppProps.context} property since you
+        This property is recommended over the ``AppProps.context`` property since you
         can make final decision over which context value to take in your app.
 
         Context can be read from any construct using ``node.getContext(key)``.
@@ -681,13 +638,13 @@ class PDKNagAppProps(aws_cdk.AppProps):
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def nag_packs(self) -> typing.Optional[typing.List[cdk_nag.NagPack]]:
+    def nag_packs(self) -> typing.Optional[typing.List[_cdk_nag_263d9695.NagPack]]:
         '''Custom nag packs to execute.
 
         :default: DEFAULT_NAG_PACKS
         '''
         result = self._values.get("nag_packs")
-        return typing.cast(typing.Optional[typing.List[cdk_nag.NagPack]], result)
+        return typing.cast(typing.Optional[typing.List[_cdk_nag_263d9695.NagPack]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -711,3 +668,74 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ac3cb3e86fec8343c8cfd3250603139c2b784e953e810dd5f4ec86bea8647470(
+    node: _constructs_77d1e7e8.IConstruct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8b4717233c383e92aee07f5c5bfaaf9ba416f2612bb2527190abf127c7d11614(
+    *,
+    message_description: builtins.str,
+    message_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__466a7c08b7dcfd34459cbd9fbc047f17fa25c1fe7475d27c9da99cbe48725576(
+    *,
+    messages: typing.Sequence[typing.Union[Message, typing.Dict[builtins.str, typing.Any]]],
+    resource: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eacd5d6263c6650ef92801e14df0e8496ba14fc314027ecdc8ab17feeb1ee6cb(
+    stack: _aws_cdk_ceddda9d.Stack,
+    path: builtins.str,
+    suppressions: typing.Sequence[typing.Union[_cdk_nag_263d9695.NagPackSuppression, typing.Dict[builtins.str, typing.Any]]],
+    apply_to_children: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f531ce8dc9530de5f5a780dfb0a7d65e878015fc527a8a2910fa6ff9524c076b(
+    stack: _aws_cdk_ceddda9d.Stack,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4c4670d27463fdb902c062007f0ce99b8693abca99d353e2cfa1717c0ef5c2ca(
+    stack: _aws_cdk_ceddda9d.Stack,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2c7f927b35737240cc577c142b301cdf0a408f1b8d83de2f004c52b876d04688(
+    stack: _aws_cdk_ceddda9d.Stack,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3a89a363b3c85ca82ba617bc4d5467add15ae50a34fde9d5a6c3050821178320(
+    stack: _aws_cdk_ceddda9d.Stack,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e3e803ce90b5c2282434281a79f47263fc4a4888d6182a6d59c4b475a73fc399(
+    *,
+    analytics_reporting: typing.Optional[builtins.bool] = None,
+    auto_synth: typing.Optional[builtins.bool] = None,
+    context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    outdir: typing.Optional[builtins.str] = None,
+    post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    stack_traces: typing.Optional[builtins.bool] = None,
+    tree_metadata: typing.Optional[builtins.bool] = None,
+    fail_on_error: typing.Optional[builtins.bool] = None,
+    fail_on_warning: typing.Optional[builtins.bool] = None,
+    nag_packs: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagPack]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
